// ******* Cel-Shading Shader *******
// by Raphael Mun

//-----------------------------------------------------------------------------
// Effect File Variables
//-----------------------------------------------------------------------------

float4x4 worldViewProj : WorldViewProjection; // This matrix will be loaded by the application
float3 lightDir;

texture Texture0; // This texture will be loaded by the application
texture celTexture; // This texture will be loaded by the application

sampler Sampler = sampler_state
{
    Texture   = (Texture0);
    MipFilter = LINEAR;
    MinFilter = LINEAR;
    MagFilter = LINEAR;
};

sampler CelSampler = sampler_state
{
    Texture   = (celTexture);
    MipFilter = LINEAR;
    MinFilter = LINEAR;
    MagFilter = None;
};

//-----------------------------------------------------------------------------
// Vertex Definitions
//-----------------------------------------------------------------------------

// Our sample application will send vertices 
// down the pipeline laid-out like this...

struct VS_INPUT
{
    float3 pos : POSITION;
    float3 nor : NORMAL;
    float2 texture0 : TEXCOORD0;
};

// Once the vertex shader is finished, it will 
// pass the vertices on to the pixel shader like this...

struct VS_OUTPUT
{
    float4 pos : POSITION;
    float2 texture0  : TEXCOORD0;
    float2 texture1  : TEXCOORD1;
    float4 color     : COLOR0;
};

// And finally, the pixel shader will send a single 
// color value to the frame buffer like this...

struct PS_OUTPUT
{
    float4 color : COLOR;
};

//-----------------------------------------------------------------------------
// Simple Vertex Shader
//-----------------------------------------------------------------------------

VS_OUTPUT myvs( VS_INPUT IN )
{
    VS_OUTPUT OUT;
    float3 transNormal; // Transformed Normal
    float lightAngle;

    OUT.pos = mul( worldViewProj, float4(IN.pos, 1) );
    transNormal = mul ( worldViewProj, float4(IN.nor, 0) );
    lightAngle = dot(normalize(lightDir), normalize(transNormal))*0.5f + 0.5f;
    if (lightAngle < 0.0f)
        lightAngle = 0.0f;
    if (lightAngle > 1.0f)
        lightAngle = 1.0f;

    OUT.color = float4( 1.0, 1.0, 1.0, 1.0 ); // Pass white as a default color
    //OUT.color = float4( 0.0, 1.0, 0.0, 1.0 ); // Pass green to test vertex shader
    //if (lightAngle < 0.0f)
    //    OUT.color = float4( 0.0, 1.0, 0.0, 1.0 ); // Pass green to test vertex shader
    //else if (lightAngle < 0.2f)
    //    OUT.color = float4( 1.0, 0.0, 0.0, 1.0 ); // Pass red to test vertex shader
    //else
    //    OUT.color = float4( 0.0, 0.0, 1.0, 1.0 ); // Pass blue to test vertex shader

    OUT.texture0 = IN.texture0;
    OUT.texture1 = float2(lightAngle,0.5f);

    return OUT;
}

//-----------------------------------------------------------------------------
// Simple Pixel Shader
//-----------------------------------------------------------------------------

PS_OUTPUT myps( VS_OUTPUT IN )
{
    PS_OUTPUT OUT;

    OUT.color = tex2D( CelSampler, IN.texture1 ) * tex2D( Sampler, IN.texture0 ) * IN.color;

	// If you uncomment the next line, the color passed to us by our
    // vertex shader and the selected texture sampler will be ignored 
	// completely and all output to the frame buffer will be blue regardless.

	//OUT.color = float4( 0.0, 0.0, 1.0, 1.0);

    return OUT;
}

//-----------------------------------------------------------------------------
// Simple Effect (1 technique with 1 pass)
//-----------------------------------------------------------------------------

technique Technique0
{
    pass Pass0
    {
		Lighting = FALSE;

		//Sampler[0] = (Sampler); // Needed by pixel shader
		//Sampler[1] = (CelSampler);

		VertexShader = compile vs_1_1 myvs();
		PixelShader  = compile ps_1_1 myps();
    }
}

